/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0}, {1}. {2}"

, "Recurrances"
: "Ponavljanja"

, "No recurring rule defined"
: "Niti jedno pravilo ponavljanja nije definirano"

, "Details"
: "Detalji"

, "None"
: "Niti jedno"

, "Daily"
: "Dnevno"

, "Weekly"
: "Tjedno"

, "Monthly"
: "Mjesečno"

, "Yearly"
: "Godišnje"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Iznimke od ponavljajućeg događaja ne mogu i same imati ponavljanja"

, "at"
: "u"

, "never"
: "nikad"

, "after {0} occurrences"
: "nakon {0} pojavljivanja"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Kraj"

, "Until has to be after event start"
: "Do mora biti nakon početka događaja"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Svaki {0}. dan"

, "Every {0}. Week at"
: "Svaki {0}. tjedan u"

, "Every {0}. Month"
: "Svaki {0}. mjesec"

, "at the"
: "u"

, "first"
: "prvi"

, "second"
: "drugi"

, "third"
: "treći"

, "fourth"
: "četvrti"

, "last"
: "zadnji"

, "Every {0}. Year"
: "Svake {0}. godine"

, "of"
: "od"

, "Summary"
: "Sažetak"

, "Organizer"
: "Organizator"

, "Description"
: "Opis"

, "Location"
: "Lokacija"

, "Start Time"
: "Početno vrijeme"

, "End Time"
: "Završno vrijeme"

, "Attendee"
: "Sudionik"

, "whole day"
: "cijeli dan"

, "Week {0} :"
: "Tjedan {0}:"

, "Poll, Polls"
: [
  ""
 ,""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Novi događaj"

, "Calendar, Calendars"
: [
  "Kalendar"
 ,"Kalendara"
 ,"Kalendara"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Dodaj sudionike"

, "Sort Attendee"
: ""

, "Check to filter for this attendee"
: "Označite za filtriranje ovog sudionika"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Učitavanje događaja, molimo pričekajte..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Ispiši stranicu"

, "Loose-Leaf"
: ""

, "Sheet"
: "List"

, "Grid"
: "Tablično"

, "Timeline"
: ""

, "Day"
: "Dan"

, "Week"
: "Tjedan"

, "Month"
: "Mjesec"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Postavi moj odgovor"

, "Copy {0}"
: "Kopiraj {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Ažuriranje događaja u prošlosti"

, "Update this event"
: "Ažurirajte ovaj događaj"

, "Do not update this event"
: "Nemojte ažurirati ovaj događaj"

, "Creating event in the past"
: "Stvaranje događaja u prošlosti"

, "Create this event"
: "Napravite događaj"

, "Do not create this event"
: "Nemojte stvarati ovaj događaj"

, "Update this event only"
: "Ažuriraj samo ovaj događaj"

, "Update this and all future events"
: "Ažurirajte ovaj i sve buduće događaje"

, "Update whole series"
: "Ažuriraj cijelu seriju"

, "Update nothing"
: "Nemoj ažurirati ništa"

, "Update Event"
: "Ažuriraj događaj"

, "Please Change Selection"
: "Molimo izmijenite odabir"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "Vaš odabir sadrži ponavljajuće događaje. Ponavljani događaji moraju biti izbrisani odvojeno!"

, "Delete Event"
: "Obriši događaj"

, "Delete this event only"
: "Obriši samo ovaj događaj"

, "Delete this and all future events"
: "Obriši ovaj i sve buduće događaje"

, "Delete whole series"
: "Obriši cijelu seriju"

, "Delete nothing"
: "Ništa nije izbrisano"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Da li zaista želite obrisati ovaj događaj?"
 ,"Da li zaista želite obrisati odabrane događaje?"
 ,"Da li zaista želite obrisati odabrane događaje?"

]
, "Could not Print"
: "Neuspješan ispis na pisač"

, "Sorry, your current view does not support printing."
: "Vaš trenutni pregled nije podržan za ispis na pisaš."

, "Scheduling Conflict"
: "Konflikt u događajima"

, "The following attendee are busy at the requested time:"
: "Slijedeći sudionici su zauzeti u traženo vrijeme:"

, "Ignore Conflict"
: "Ignoriraj konflikt"

, "Edit Event"
: "Uredi događaj"

, "Cancel this action"
: "Otkaži ovu akciju"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Upravljanje resursima"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Odaberite sudionika"

, "Attachments"
: ""

, "Private"
: "Privatno"

, "Tags"
: "Oznake"

, "Blocking"
: "Blokirajući"

, "Tentative"
: "Uvjetan"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "privatna klasifikacija"

, "recurring event"
: "ponavljajući događaj"

, "recurring event exception"
: "iznimka od ponavljanja događaja"

, "has alarm"
: "ima alarm"

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini Kalendar"

, "WK"
: "Td"

, "{0} more..."
: "{0} više..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Molimo izaberite događaj za dodavanje kontakata"

, "Role"
: "Uloga"

, "Select Role"
: "Odaberite ulogu"

, "Status"
: "Status"

, "Select Status"
: "Odaberite status"

, "Adding {0} Attendee to event"
: "Dodavanje {0} sudionika na događaju"

, "no events found"
: "Događaji nisu pronađeni"

, "Searching..."
: "Tražim..."

, "Search Event"
: "Traži događaje"

, "Event, Events"
: [
  "Događaj"
 ,"Događaja"
 ,"Događaja"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "nije blokirajući"

, "Displayed in"
: "Prikaži u"

, "No Information"
: "Nema informacija"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Događaji"

, "Calendars"
: "Kalendari"

, "Quick Search"
: ""

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Status sudionika"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Uloge sudjelovanja "

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Klasifikacija"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "{0} {1} sati"

, "Event (as attendee)"
: "Događaj (kao sudionik)"

, "Event (as organizer)"
: "Događaj (kao organizator)"

, "Event attendee"
: "Događaj sudionik"

, "Attender, Attendee"
: [
  "Sudionik"
 ,"Sudionika"
 ,"Sudionika"

]
, "Resource, Resources"
: [
  "Resurs"
 ,"Resursa"
 ,"Resursa"

]
, "Resources"
: "Resursi"

, "Anyone"
: ""

, "Name"
: "Ime"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Tip"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Kliknite ovdje za pozivanje drugih sudionika"

, "User"
: "Korisnik"

, "Group"
: "Grupa"

, "Member of group"
: "Član grupe"

, "This is the calendar where the attender has saved this event in"
: "Ovo je kalendar u koji je sudionik spremio ovaj događaj"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Ukloni sudionika"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(kao član grupe)"

, "External Attendee"
: "Vanjski sudionici"

, "Originally"
: "Izvorno"

, "Checking Calendar Data..."
: "Provjera podataka kalendara..."

, "Reply to Recurring Event"
: "Odgovor na ponavljajući događaj"

, "You are responding to an recurring event. What would you like to do?"
: "Vi ste reagirati na ponavljajući događaj. Što želite učiniti?"

, "Respond to whole series"
: "Odgovorite na cijelom nizu"

, "Do not respond"
: "Ne reagira"

, "The event of this message does not exist"
: "Događaj ove poruke ne postoji"

, "The sender is not authorised to update the event"
: "Pošiljatelj nije ovlašten ažurirati događaj"

, "This message is already processed"
: "Ova poruka je već obrađena"

, "You are not an attendee of this event"
: "Niste sudionik ovog događaja"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Nepodržana poruka"

, "This is an event invitation for someone else."
: "Ovo je događaj namijenjen za nekoga drugog."

, "You have already replied to this event invitation."
: "Već ste odgovorili na ovaj poziv."

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Dobili ste pozivnicu za događaj. Postavite svoj ​​odgovor na:"

, "An invited attendee responded to the invitation."
: "Pozvani sudionik odazvao se pozivu."

, "Unsupported method"
: "Nepodržana metoda"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Unesite opis..."

, "Grants"
: "Dozvole"

, "This event is originally stored in a calendar you don't have access to."
: "Ovaj događaj je izvorno pohranjen u kalendaru u koji nemate pristup."

, "This event is originally stored in {0}"
: "Ovaj događaj je izvorno pohranjen u {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Ovaj događaj dodatno je prikazan u tvoj osobni kalendar {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Pregled"

, "Saved in"
: "Spremljeno u"

, "Enter description"
: "Unesite opis"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Datum završetka nije pravilan"

, "End date must be after start date"
: "Datum završetka mora biti poslije datuma početka"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Datum početka nije pravilan"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "Sažetak ne smije biti duže od 255 znakova."

, "The summary must have at least 1 character."
: "Sažetak mora imati barem jedan znak."

, "Summary too Long"
: "Sažetak je predug"

, "Summary too Short"
: "Sažetak je prekratak"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Svi moji događaji"

, "Position on the left time axis, day and week view should start with"
: "Pozicija na lijevoj strani vremenske osi, dan i tjedan s kojim bi pregled trebao započeti"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Početni kalendar"

, "The default calendar for invitations and new events"
: "Početni kalendar za pozivnice i nove događaje"

, "Default Favorite"
: "Početni favorit"

, "The default favorite which is loaded on calendar startup"
: "Početni favorit koji se učitava prilikom starta kalendara"

, "Get Notification Emails"
: "Zaprimanje email obavijesti"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Nivo akcija za koje želite biti obavijesšteni. Uzmite u obzir da će organizator biti obaviješten o svim izmjenama uključujući odogovre sudionika ukoliko nije odabrana opcija \"Nikada\""

, "Send Notifications Emails of own Actions"
: "Slanje email obavijesti o vlastitim akcijama"

, "Get notifications emails for actions you did yourself"
: "Zaprimanje email obavijesti o akcijama koje ste sami napravili"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Omogućiti standardni alarm"

, "New events get a standard alarm as defined below"
: "Novi događaji dobije standardni alarm kao što je definirano u nastavku"

, "Standard Alarm Time"
: "Standardna vrijeme alarma"

, "Minutes before the event starts"
: "Minuta prije nego događaj započne"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Fiksni kalendar"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Nikada"

, "On invitation and cancellation only"
: "Samo kod pozivanja i otkazivanja"

, "On time changes"
: "Na promjeni vrijemena"

, "On all updates but attendee responses"
: "Na svim promjenama, ali odgovora sudionika"

, "On attendee responses too"
: "Na sudionik odgovora isto"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Kalendari su uvijek odabrani bez obzira na parametare u filtru. Stoga postoji mogućnost da se uporno prikazuju određeni neradni dani u kalendaru."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Status za sudjelovanje je dostupan"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Bez odgovora"

, "Accepted"
: "Prihvaćeno"

, "Declined"
: "Odbijeno"

, "Attendee Roles Available"
: "Raspoložive uloge sudionika"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Obavezno"

, "Optional"
: "Opcionalno"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "%s osobni kalendar"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "nepoznato"

, "This contact has been automatically added by the system as an event attender"
: "Ovaj kontakt je automatski dodan od strane sustava kao sudionik događaja"

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "Početak"

, "Priority"
: "Prioritet"

, "Url"
: "URL"

, "Recurrance rule"
: "Pravilo ponavljanja"

, "Is all day event"
: "Događaj za cijeli dan"

, "Organizer timezone"
: "Vremenska zona organizatora"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Alarm za događaj \"%1$s\" u %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Pozivnica za događaj \"%1$s\" u %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "Događaj \"%1$s\" u %2$s je otkazan"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Događaj \"%1$s\" premješteno je s%2$s%3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "Događaj \"%1$s\" u %2$s je ažuriran"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s je prihvatio/la događaj \"%2$s\" u %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s je odbio/la događaj \"%2$s\" u %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "Odgovor o mogućem dolasku od %1$s za događaj \"%2$s\" u %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Nema odgovora od %1$s za događaj \"%2$s\" u %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Izmjena sudionika za događaj \"%1$s\" u %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Izmjene"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s izmijenjen iz \"%2$s\" u \"%3$s\""

, "%1$s has been invited"
: "%1$s je pozvan/a"

, "%1$s has been removed"
: "%1$s je uklonjen"

, "%1$s accepted invitation"
: "%1$s je prihvatio/la poziv"

, "%1$s declined invitation"
: "%1$s je odbio/la poziv"

, "Tentative response from %1$s"
: "Uvjetno odgovor od %1s"

, "No response from %1$s"
: "Nema odogovra od %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" odgovor iz %1s"

, "Link"
: ""

, "Event details"
: "Detalji odgađaja"

, "All events I attend"
: "Svi događaji kojima sam prisustvovao"

, "Awaiting response"
: "U čekanju odgovora"

, "Events I have not yet responded to"
: "Događaji na koje nisam odgovorio"

, "Declined events"
: "Odbijeni događaji"

, "Events I have declined"
: "Događaji koje sam odbio"

, "I'm organizer"
: "Ja sam organizator"

, "Events I'm the organizer of"
: "Događaji koje sam ja organizirao"

, "manage shared calendars"
: "Upravljanje dijeljenim kalendarima"

, "Create new shared calendars"
: "Kreiranje novog dijeljenog kalendara"

, "manage shared calendars favorites"
: "Upravljanje dijeljenim favoritima kalendara"

, "Create or update shared calendars favorites"
: "Kreiranje ili izmjena dijeljenih favorita kalendara"

, "manage resources"
: "Upravljanje resursima"

, "All Rights to administrate resources"
: "Sva prava za administriranje resursa"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Kalendar"

, "Do you really want to delete this event?"
: "Da li zaista želite obrisati ovaj događaj?"

, "Resource Grant"
: ""

, "Event"
: "Događaj"

, "Attender"
: "Sudionik"

, "Resource"
: "Resurs"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
